# CKEditor 5 Readability Module

## Introduction

The CKEditor 5 Readability module enhances the CKEditor 5 text editor in
Drupal by adding real-time readability analysis functionality.
This module helps content creators write more accessible and user-friendly
content by providing instant feedback on text complexity using Flesch-Kincaid scoring.

## Features

- Adds a readability analysis button to the CKEditor 5 toolbar
- Real-time calculation of Flesch Reading Ease scores as you type
- Visual feedback with color-coded difficulty indicators (green/yellow/red)
- Detailed analysis modal showing grade level and difficulty interpretation
- Complete scoring guide with reading level explanations
- Smart text processing with HTML stripping and advanced syllable counting

## Requirements

- Drupal 10.x or 11.x
- CKEditor 5 module enabled
- Modern browser with ES6+ JavaScript support

## Installation

1. Run the command `composer require drupal/ckeditor_readability`.
2. Enable the module through the Drupal admin interface or using Drush:
   ```
   drush en ckeditor_readability
   ```

## Configuration

1. Go to Administration > Configuration > Content Authoring >
Text formats and editors
2. Edit the desired text format that uses CKEditor 5
3. In the toolbar configuration, add the "Readability Score" button to
your active toolbar
4. Save the configuration

## Usage

1. When editing content, the readability button will appear in the CKEditor
toolbar showing your current readability score
2. The button color indicates difficulty level:
   - **Green**: Easy to read (score 70+)
   - **Yellow**: Moderate difficulty (score 50-69)
   - **Red**: Difficult to read (score below 50)
3. Click the readability button to open a detailed analysis modal showing:
   - Flesch Reading Ease Score
   - Flesch-Kincaid Grade Level
   - Difficulty interpretation
   - Complete scoring guide
4. The analysis updates automatically as you type (with a 1-second delay)

## Contributing

Contributions to the CKEditor 5 Readability module are welcome.
Please follow [Drupal coding standards](https://www.drupal.org/docs/develop/standards) when submitting patches or pull requests.

## License

This module is licensed under the GNU General Public License v2.0 or later.

## Maintainers

- [Abderrahim GHAZALI] - https://www.drupal.org/u/abdei

For bug reports, feature requests, and support, please use the [issue queue on Drupal.org](https://www.drupal.org/project/issues/ckeditor_readability). 